package F5::REST::WAF::ConvertPolicy;

use strict;
use warnings;

use File::Slurp qw(read_file);

use F5::Deploy;
use F5::Policy::Convert;

use base ('F5::REST::WAF');

#----------------------------------------------------------------------

sub process {
    my ($self, %params) = @_;

    my $c = $self->{connection};

    my $output_filename = $c->param('output-filename');
    my $source_policy_file = $c->req->upload('source-policy');
    if (! $source_policy_file) {
        $c->render(json => { message => "Source policy file not found" }, status => 404);
        return;
    }
    my $filename = $source_policy_file->filename;

    my $tmp_path = F5::Deploy::get_path_by_type('tmp');
    my $timestamp = time();
    my $import_filename = "$tmp_path/waf_upload_${timestamp}_". $filename;
    my $export_filename = "$tmp_path/waf_download_${timestamp}_". $output_filename;
    $source_policy_file->asset->move_to($import_filename);

    my %convert_policy_params = (
        export_file => $export_filename,
        import_file => $import_filename,
        format => 'json',
        full_export => 1,
    );

    my $result;
    eval {
        my $converter = F5::Policy::Convert->new(logger => $self->{logger},);
        $result = $converter->convert_policy(%convert_policy_params);
    };

    if ($@) {
        $c->render(json => { message => $@ }, status => 404);
    }
    else {
        if ($result->{completed_successfully}) {
            my $content = read_file($result->{filename});
            $c->res->headers->content_type("application/x-download");
            $c->res->headers->content_disposition("attachment; filename=\"$output_filename\"");
            $c->render(data => $content);
        }
        else {
            $c->render(json => $result, status => 404);
        }
    }

    unlink $import_filename if -e $import_filename;
    unlink $export_filename if -e $export_filename;
}

#----------------------------------------------------------------------

1;

